# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateLogDetails(object):
    """
    The details to create a log object.
    """

    #: A constant which can be used with the log_type property of a CreateLogDetails.
    #: This constant has a value of "CUSTOM"
    LOG_TYPE_CUSTOM = "CUSTOM"

    #: A constant which can be used with the log_type property of a CreateLogDetails.
    #: This constant has a value of "SERVICE"
    LOG_TYPE_SERVICE = "SERVICE"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateLogDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this CreateLogDetails.
        :type display_name: str

        :param log_type:
            The value to assign to the log_type property of this CreateLogDetails.
            Allowed values for this property are: "CUSTOM", "SERVICE"
        :type log_type: str

        :param is_enabled:
            The value to assign to the is_enabled property of this CreateLogDetails.
        :type is_enabled: bool

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateLogDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateLogDetails.
        :type freeform_tags: dict(str, str)

        :param configuration:
            The value to assign to the configuration property of this CreateLogDetails.
        :type configuration: oci.logging.models.Configuration

        :param retention_duration:
            The value to assign to the retention_duration property of this CreateLogDetails.
        :type retention_duration: int

        """
        self.swagger_types = {
            'display_name': 'str',
            'log_type': 'str',
            'is_enabled': 'bool',
            'defined_tags': 'dict(str, dict(str, object))',
            'freeform_tags': 'dict(str, str)',
            'configuration': 'Configuration',
            'retention_duration': 'int'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'log_type': 'logType',
            'is_enabled': 'isEnabled',
            'defined_tags': 'definedTags',
            'freeform_tags': 'freeformTags',
            'configuration': 'configuration',
            'retention_duration': 'retentionDuration'
        }

        self._display_name = None
        self._log_type = None
        self._is_enabled = None
        self._defined_tags = None
        self._freeform_tags = None
        self._configuration = None
        self._retention_duration = None

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this CreateLogDetails.
        The user-friendly display name. This must be unique within the enclosing resource,
        and it's changeable. Avoid entering confidential information.


        :return: The display_name of this CreateLogDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateLogDetails.
        The user-friendly display name. This must be unique within the enclosing resource,
        and it's changeable. Avoid entering confidential information.


        :param display_name: The display_name of this CreateLogDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def log_type(self):
        """
        **[Required]** Gets the log_type of this CreateLogDetails.
        The logType that the log object is for, whether custom or service.

        Allowed values for this property are: "CUSTOM", "SERVICE"


        :return: The log_type of this CreateLogDetails.
        :rtype: str
        """
        return self._log_type

    @log_type.setter
    def log_type(self, log_type):
        """
        Sets the log_type of this CreateLogDetails.
        The logType that the log object is for, whether custom or service.


        :param log_type: The log_type of this CreateLogDetails.
        :type: str
        """
        allowed_values = ["CUSTOM", "SERVICE"]
        if not value_allowed_none_or_none_sentinel(log_type, allowed_values):
            raise ValueError(
                "Invalid value for `log_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._log_type = log_type

    @property
    def is_enabled(self):
        """
        Gets the is_enabled of this CreateLogDetails.
        Whether or not this resource is currently enabled.


        :return: The is_enabled of this CreateLogDetails.
        :rtype: bool
        """
        return self._is_enabled

    @is_enabled.setter
    def is_enabled(self, is_enabled):
        """
        Sets the is_enabled of this CreateLogDetails.
        Whether or not this resource is currently enabled.


        :param is_enabled: The is_enabled of this CreateLogDetails.
        :type: bool
        """
        self._is_enabled = is_enabled

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateLogDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateLogDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateLogDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateLogDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateLogDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateLogDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateLogDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateLogDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def configuration(self):
        """
        Gets the configuration of this CreateLogDetails.

        :return: The configuration of this CreateLogDetails.
        :rtype: oci.logging.models.Configuration
        """
        return self._configuration

    @configuration.setter
    def configuration(self, configuration):
        """
        Sets the configuration of this CreateLogDetails.

        :param configuration: The configuration of this CreateLogDetails.
        :type: oci.logging.models.Configuration
        """
        self._configuration = configuration

    @property
    def retention_duration(self):
        """
        Gets the retention_duration of this CreateLogDetails.
        Log retention duration in 30-day increments (30, 60, 90 and so on).


        :return: The retention_duration of this CreateLogDetails.
        :rtype: int
        """
        return self._retention_duration

    @retention_duration.setter
    def retention_duration(self, retention_duration):
        """
        Sets the retention_duration of this CreateLogDetails.
        Log retention duration in 30-day increments (30, 60, 90 and so on).


        :param retention_duration: The retention_duration of this CreateLogDetails.
        :type: int
        """
        self._retention_duration = retention_duration

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TargetResponderRecipeResponderRuleSummary(object):
    """
    Summary of ResponderRule.
    """

    #: A constant which can be used with the type property of a TargetResponderRecipeResponderRuleSummary.
    #: This constant has a value of "REMEDIATION"
    TYPE_REMEDIATION = "REMEDIATION"

    #: A constant which can be used with the type property of a TargetResponderRecipeResponderRuleSummary.
    #: This constant has a value of "NOTIFICATION"
    TYPE_NOTIFICATION = "NOTIFICATION"

    #: A constant which can be used with the supported_modes property of a TargetResponderRecipeResponderRuleSummary.
    #: This constant has a value of "AUTOACTION"
    SUPPORTED_MODES_AUTOACTION = "AUTOACTION"

    #: A constant which can be used with the supported_modes property of a TargetResponderRecipeResponderRuleSummary.
    #: This constant has a value of "USERACTION"
    SUPPORTED_MODES_USERACTION = "USERACTION"

    #: A constant which can be used with the lifecycle_state property of a TargetResponderRecipeResponderRuleSummary.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a TargetResponderRecipeResponderRuleSummary.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a TargetResponderRecipeResponderRuleSummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a TargetResponderRecipeResponderRuleSummary.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a TargetResponderRecipeResponderRuleSummary.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a TargetResponderRecipeResponderRuleSummary.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a TargetResponderRecipeResponderRuleSummary.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new TargetResponderRecipeResponderRuleSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this TargetResponderRecipeResponderRuleSummary.
        :type id: str

        :param display_name:
            The value to assign to the display_name property of this TargetResponderRecipeResponderRuleSummary.
        :type display_name: str

        :param description:
            The value to assign to the description property of this TargetResponderRecipeResponderRuleSummary.
        :type description: str

        :param type:
            The value to assign to the type property of this TargetResponderRecipeResponderRuleSummary.
            Allowed values for this property are: "REMEDIATION", "NOTIFICATION", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        :param policies:
            The value to assign to the policies property of this TargetResponderRecipeResponderRuleSummary.
        :type policies: list[str]

        :param supported_modes:
            The value to assign to the supported_modes property of this TargetResponderRecipeResponderRuleSummary.
            Allowed values for items in this list are: "AUTOACTION", "USERACTION", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type supported_modes: list[str]

        :param details:
            The value to assign to the details property of this TargetResponderRecipeResponderRuleSummary.
        :type details: oci.cloud_guard.models.ResponderRuleDetails

        :param compartment_id:
            The value to assign to the compartment_id property of this TargetResponderRecipeResponderRuleSummary.
        :type compartment_id: str

        :param time_created:
            The value to assign to the time_created property of this TargetResponderRecipeResponderRuleSummary.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this TargetResponderRecipeResponderRuleSummary.
        :type time_updated: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this TargetResponderRecipeResponderRuleSummary.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this TargetResponderRecipeResponderRuleSummary.
        :type lifecycle_details: str

        """
        self.swagger_types = {
            'id': 'str',
            'display_name': 'str',
            'description': 'str',
            'type': 'str',
            'policies': 'list[str]',
            'supported_modes': 'list[str]',
            'details': 'ResponderRuleDetails',
            'compartment_id': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'display_name': 'displayName',
            'description': 'description',
            'type': 'type',
            'policies': 'policies',
            'supported_modes': 'supportedModes',
            'details': 'details',
            'compartment_id': 'compartmentId',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails'
        }

        self._id = None
        self._display_name = None
        self._description = None
        self._type = None
        self._policies = None
        self._supported_modes = None
        self._details = None
        self._compartment_id = None
        self._time_created = None
        self._time_updated = None
        self._lifecycle_state = None
        self._lifecycle_details = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this TargetResponderRecipeResponderRuleSummary.
        Identifier for ResponderRule.


        :return: The id of this TargetResponderRecipeResponderRuleSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this TargetResponderRecipeResponderRuleSummary.
        Identifier for ResponderRule.


        :param id: The id of this TargetResponderRecipeResponderRuleSummary.
        :type: str
        """
        self._id = id

    @property
    def display_name(self):
        """
        Gets the display_name of this TargetResponderRecipeResponderRuleSummary.
        ResponderRule Display Name


        :return: The display_name of this TargetResponderRecipeResponderRuleSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this TargetResponderRecipeResponderRuleSummary.
        ResponderRule Display Name


        :param display_name: The display_name of this TargetResponderRecipeResponderRuleSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this TargetResponderRecipeResponderRuleSummary.
        ResponderRule Description


        :return: The description of this TargetResponderRecipeResponderRuleSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this TargetResponderRecipeResponderRuleSummary.
        ResponderRule Description


        :param description: The description of this TargetResponderRecipeResponderRuleSummary.
        :type: str
        """
        self._description = description

    @property
    def type(self):
        """
        Gets the type of this TargetResponderRecipeResponderRuleSummary.
        Type of Responder

        Allowed values for this property are: "REMEDIATION", "NOTIFICATION", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The type of this TargetResponderRecipeResponderRuleSummary.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this TargetResponderRecipeResponderRuleSummary.
        Type of Responder


        :param type: The type of this TargetResponderRecipeResponderRuleSummary.
        :type: str
        """
        allowed_values = ["REMEDIATION", "NOTIFICATION"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            type = 'UNKNOWN_ENUM_VALUE'
        self._type = type

    @property
    def policies(self):
        """
        Gets the policies of this TargetResponderRecipeResponderRuleSummary.
        List of Policy


        :return: The policies of this TargetResponderRecipeResponderRuleSummary.
        :rtype: list[str]
        """
        return self._policies

    @policies.setter
    def policies(self, policies):
        """
        Sets the policies of this TargetResponderRecipeResponderRuleSummary.
        List of Policy


        :param policies: The policies of this TargetResponderRecipeResponderRuleSummary.
        :type: list[str]
        """
        self._policies = policies

    @property
    def supported_modes(self):
        """
        Gets the supported_modes of this TargetResponderRecipeResponderRuleSummary.
        Supported Execution Modes

        Allowed values for items in this list are: "AUTOACTION", "USERACTION", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The supported_modes of this TargetResponderRecipeResponderRuleSummary.
        :rtype: list[str]
        """
        return self._supported_modes

    @supported_modes.setter
    def supported_modes(self, supported_modes):
        """
        Sets the supported_modes of this TargetResponderRecipeResponderRuleSummary.
        Supported Execution Modes


        :param supported_modes: The supported_modes of this TargetResponderRecipeResponderRuleSummary.
        :type: list[str]
        """
        allowed_values = ["AUTOACTION", "USERACTION"]
        if supported_modes:
            supported_modes[:] = ['UNKNOWN_ENUM_VALUE' if not value_allowed_none_or_none_sentinel(x, allowed_values) else x for x in supported_modes]
        self._supported_modes = supported_modes

    @property
    def details(self):
        """
        Gets the details of this TargetResponderRecipeResponderRuleSummary.

        :return: The details of this TargetResponderRecipeResponderRuleSummary.
        :rtype: oci.cloud_guard.models.ResponderRuleDetails
        """
        return self._details

    @details.setter
    def details(self, details):
        """
        Sets the details of this TargetResponderRecipeResponderRuleSummary.

        :param details: The details of this TargetResponderRecipeResponderRuleSummary.
        :type: oci.cloud_guard.models.ResponderRuleDetails
        """
        self._details = details

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this TargetResponderRecipeResponderRuleSummary.
        Compartment Identifier


        :return: The compartment_id of this TargetResponderRecipeResponderRuleSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this TargetResponderRecipeResponderRuleSummary.
        Compartment Identifier


        :param compartment_id: The compartment_id of this TargetResponderRecipeResponderRuleSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def time_created(self):
        """
        Gets the time_created of this TargetResponderRecipeResponderRuleSummary.
        The date and time the target responder recipe rule was created. Format defined by RFC3339.


        :return: The time_created of this TargetResponderRecipeResponderRuleSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this TargetResponderRecipeResponderRuleSummary.
        The date and time the target responder recipe rule was created. Format defined by RFC3339.


        :param time_created: The time_created of this TargetResponderRecipeResponderRuleSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this TargetResponderRecipeResponderRuleSummary.
        The date and time the target responder recipe rule was updated. Format defined by RFC3339.


        :return: The time_updated of this TargetResponderRecipeResponderRuleSummary.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this TargetResponderRecipeResponderRuleSummary.
        The date and time the target responder recipe rule was updated. Format defined by RFC3339.


        :param time_updated: The time_updated of this TargetResponderRecipeResponderRuleSummary.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this TargetResponderRecipeResponderRuleSummary.
        The current state of the ResponderRule.

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this TargetResponderRecipeResponderRuleSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this TargetResponderRecipeResponderRuleSummary.
        The current state of the ResponderRule.


        :param lifecycle_state: The lifecycle_state of this TargetResponderRecipeResponderRuleSummary.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this TargetResponderRecipeResponderRuleSummary.
        A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.


        :return: The lifecycle_details of this TargetResponderRecipeResponderRuleSummary.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this TargetResponderRecipeResponderRuleSummary.
        A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.


        :param lifecycle_details: The lifecycle_details of this TargetResponderRecipeResponderRuleSummary.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Query(object):
    """
    The query to filter and aggregate.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Query object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this Query.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this Query.
        :type compartment_id: str

        :param query_definition:
            The value to assign to the query_definition property of this Query.
        :type query_definition: oci.usage_api.models.QueryDefinition

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'query_definition': 'QueryDefinition'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'query_definition': 'queryDefinition'
        }

        self._id = None
        self._compartment_id = None
        self._query_definition = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this Query.
        The query OCID.


        :return: The id of this Query.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Query.
        The query OCID.


        :param id: The id of this Query.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this Query.
        The compartment OCID.


        :return: The compartment_id of this Query.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this Query.
        The compartment OCID.


        :param compartment_id: The compartment_id of this Query.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def query_definition(self):
        """
        **[Required]** Gets the query_definition of this Query.

        :return: The query_definition of this Query.
        :rtype: oci.usage_api.models.QueryDefinition
        """
        return self._query_definition

    @query_definition.setter
    def query_definition(self, query_definition):
        """
        Sets the query_definition of this Query.

        :param query_definition: The query_definition of this Query.
        :type: oci.usage_api.models.QueryDefinition
        """
        self._query_definition = query_definition

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PluggableDatabase(object):
    """
    A pluggable database (PDB) is portable collection of schemas, schema objects, and non-schema objects that appears to an Oracle client as a non-container database. To use a PDB, it needs to be plugged into a CDB.
    To use any of the API operations, you must be authorized in an IAM policy. If you are not authorized, talk to an administrator. If you are an administrator who needs to write policies to give users access, see `Getting Started with Policies`__.

    **Warning:** Oracle recommends that you avoid using any confidential information when you supply string values using the API.

    __ https://docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm
    """

    #: A constant which can be used with the lifecycle_state property of a PluggableDatabase.
    #: This constant has a value of "PROVISIONING"
    LIFECYCLE_STATE_PROVISIONING = "PROVISIONING"

    #: A constant which can be used with the lifecycle_state property of a PluggableDatabase.
    #: This constant has a value of "AVAILABLE"
    LIFECYCLE_STATE_AVAILABLE = "AVAILABLE"

    #: A constant which can be used with the lifecycle_state property of a PluggableDatabase.
    #: This constant has a value of "TERMINATING"
    LIFECYCLE_STATE_TERMINATING = "TERMINATING"

    #: A constant which can be used with the lifecycle_state property of a PluggableDatabase.
    #: This constant has a value of "TERMINATED"
    LIFECYCLE_STATE_TERMINATED = "TERMINATED"

    #: A constant which can be used with the lifecycle_state property of a PluggableDatabase.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a PluggableDatabase.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the open_mode property of a PluggableDatabase.
    #: This constant has a value of "READ_ONLY"
    OPEN_MODE_READ_ONLY = "READ_ONLY"

    #: A constant which can be used with the open_mode property of a PluggableDatabase.
    #: This constant has a value of "READ_WRITE"
    OPEN_MODE_READ_WRITE = "READ_WRITE"

    #: A constant which can be used with the open_mode property of a PluggableDatabase.
    #: This constant has a value of "MOUNTED"
    OPEN_MODE_MOUNTED = "MOUNTED"

    #: A constant which can be used with the open_mode property of a PluggableDatabase.
    #: This constant has a value of "MIGRATE"
    OPEN_MODE_MIGRATE = "MIGRATE"

    def __init__(self, **kwargs):
        """
        Initializes a new PluggableDatabase object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this PluggableDatabase.
        :type id: str

        :param container_database_id:
            The value to assign to the container_database_id property of this PluggableDatabase.
        :type container_database_id: str

        :param pdb_name:
            The value to assign to the pdb_name property of this PluggableDatabase.
        :type pdb_name: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this PluggableDatabase.
            Allowed values for this property are: "PROVISIONING", "AVAILABLE", "TERMINATING", "TERMINATED", "UPDATING", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this PluggableDatabase.
        :type lifecycle_details: str

        :param time_created:
            The value to assign to the time_created property of this PluggableDatabase.
        :type time_created: datetime

        :param connection_strings:
            The value to assign to the connection_strings property of this PluggableDatabase.
        :type connection_strings: oci.database.models.PluggableDatabaseConnectionStrings

        :param open_mode:
            The value to assign to the open_mode property of this PluggableDatabase.
            Allowed values for this property are: "READ_ONLY", "READ_WRITE", "MOUNTED", "MIGRATE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type open_mode: str

        :param is_restricted:
            The value to assign to the is_restricted property of this PluggableDatabase.
        :type is_restricted: bool

        :param compartment_id:
            The value to assign to the compartment_id property of this PluggableDatabase.
        :type compartment_id: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this PluggableDatabase.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this PluggableDatabase.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'container_database_id': 'str',
            'pdb_name': 'str',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'time_created': 'datetime',
            'connection_strings': 'PluggableDatabaseConnectionStrings',
            'open_mode': 'str',
            'is_restricted': 'bool',
            'compartment_id': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'container_database_id': 'containerDatabaseId',
            'pdb_name': 'pdbName',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'time_created': 'timeCreated',
            'connection_strings': 'connectionStrings',
            'open_mode': 'openMode',
            'is_restricted': 'isRestricted',
            'compartment_id': 'compartmentId',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._id = None
        self._container_database_id = None
        self._pdb_name = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._time_created = None
        self._connection_strings = None
        self._open_mode = None
        self._is_restricted = None
        self._compartment_id = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this PluggableDatabase.
        The `OCID`__ of the pluggable database.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The id of this PluggableDatabase.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this PluggableDatabase.
        The `OCID`__ of the pluggable database.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param id: The id of this PluggableDatabase.
        :type: str
        """
        self._id = id

    @property
    def container_database_id(self):
        """
        **[Required]** Gets the container_database_id of this PluggableDatabase.
        The `OCID`__ of the CDB.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The container_database_id of this PluggableDatabase.
        :rtype: str
        """
        return self._container_database_id

    @container_database_id.setter
    def container_database_id(self, container_database_id):
        """
        Sets the container_database_id of this PluggableDatabase.
        The `OCID`__ of the CDB.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param container_database_id: The container_database_id of this PluggableDatabase.
        :type: str
        """
        self._container_database_id = container_database_id

    @property
    def pdb_name(self):
        """
        **[Required]** Gets the pdb_name of this PluggableDatabase.
        The name for the pluggable database. The name is unique in the context of a :class:`Database`. The name must begin with an alphabetic character and can contain a maximum of thirty alphanumeric characters. Special characters are not permitted. The pluggable database name should not be same as the container database name.


        :return: The pdb_name of this PluggableDatabase.
        :rtype: str
        """
        return self._pdb_name

    @pdb_name.setter
    def pdb_name(self, pdb_name):
        """
        Sets the pdb_name of this PluggableDatabase.
        The name for the pluggable database. The name is unique in the context of a :class:`Database`. The name must begin with an alphabetic character and can contain a maximum of thirty alphanumeric characters. Special characters are not permitted. The pluggable database name should not be same as the container database name.


        :param pdb_name: The pdb_name of this PluggableDatabase.
        :type: str
        """
        self._pdb_name = pdb_name

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this PluggableDatabase.
        The current state of the pluggable database.

        Allowed values for this property are: "PROVISIONING", "AVAILABLE", "TERMINATING", "TERMINATED", "UPDATING", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this PluggableDatabase.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this PluggableDatabase.
        The current state of the pluggable database.


        :param lifecycle_state: The lifecycle_state of this PluggableDatabase.
        :type: str
        """
        allowed_values = ["PROVISIONING", "AVAILABLE", "TERMINATING", "TERMINATED", "UPDATING", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this PluggableDatabase.
        Detailed message for the lifecycle state.


        :return: The lifecycle_details of this PluggableDatabase.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this PluggableDatabase.
        Detailed message for the lifecycle state.


        :param lifecycle_details: The lifecycle_details of this PluggableDatabase.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this PluggableDatabase.
        The date and time the pluggable database was created


        :return: The time_created of this PluggableDatabase.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this PluggableDatabase.
        The date and time the pluggable database was created


        :param time_created: The time_created of this PluggableDatabase.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def connection_strings(self):
        """
        Gets the connection_strings of this PluggableDatabase.

        :return: The connection_strings of this PluggableDatabase.
        :rtype: oci.database.models.PluggableDatabaseConnectionStrings
        """
        return self._connection_strings

    @connection_strings.setter
    def connection_strings(self, connection_strings):
        """
        Sets the connection_strings of this PluggableDatabase.

        :param connection_strings: The connection_strings of this PluggableDatabase.
        :type: oci.database.models.PluggableDatabaseConnectionStrings
        """
        self._connection_strings = connection_strings

    @property
    def open_mode(self):
        """
        **[Required]** Gets the open_mode of this PluggableDatabase.
        The mode that pluggableDatabase is in. Open mode can only be changed to READ_ONLY or MIGRATE directly from the backend.

        Allowed values for this property are: "READ_ONLY", "READ_WRITE", "MOUNTED", "MIGRATE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The open_mode of this PluggableDatabase.
        :rtype: str
        """
        return self._open_mode

    @open_mode.setter
    def open_mode(self, open_mode):
        """
        Sets the open_mode of this PluggableDatabase.
        The mode that pluggableDatabase is in. Open mode can only be changed to READ_ONLY or MIGRATE directly from the backend.


        :param open_mode: The open_mode of this PluggableDatabase.
        :type: str
        """
        allowed_values = ["READ_ONLY", "READ_WRITE", "MOUNTED", "MIGRATE"]
        if not value_allowed_none_or_none_sentinel(open_mode, allowed_values):
            open_mode = 'UNKNOWN_ENUM_VALUE'
        self._open_mode = open_mode

    @property
    def is_restricted(self):
        """
        Gets the is_restricted of this PluggableDatabase.
        The restricted mode of pluggableDatabase. If a pluggableDatabase is opened in restricted mode,
        the user needs both Create a session and restricted session privileges to connect to it.


        :return: The is_restricted of this PluggableDatabase.
        :rtype: bool
        """
        return self._is_restricted

    @is_restricted.setter
    def is_restricted(self, is_restricted):
        """
        Sets the is_restricted of this PluggableDatabase.
        The restricted mode of pluggableDatabase. If a pluggableDatabase is opened in restricted mode,
        the user needs both Create a session and restricted session privileges to connect to it.


        :param is_restricted: The is_restricted of this PluggableDatabase.
        :type: bool
        """
        self._is_restricted = is_restricted

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this PluggableDatabase.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this PluggableDatabase.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this PluggableDatabase.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this PluggableDatabase.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this PluggableDatabase.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this PluggableDatabase.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this PluggableDatabase.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this PluggableDatabase.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this PluggableDatabase.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this PluggableDatabase.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this PluggableDatabase.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this PluggableDatabase.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateDomainGovernanceDetails(object):
    """
    The parameters for creating a domain governance entity.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateDomainGovernanceDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateDomainGovernanceDetails.
        :type compartment_id: str

        :param domain_id:
            The value to assign to the domain_id property of this CreateDomainGovernanceDetails.
        :type domain_id: str

        :param subscription_email:
            The value to assign to the subscription_email property of this CreateDomainGovernanceDetails.
        :type subscription_email: str

        :param ons_topic_id:
            The value to assign to the ons_topic_id property of this CreateDomainGovernanceDetails.
        :type ons_topic_id: str

        :param ons_subscription_id:
            The value to assign to the ons_subscription_id property of this CreateDomainGovernanceDetails.
        :type ons_subscription_id: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateDomainGovernanceDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateDomainGovernanceDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'domain_id': 'str',
            'subscription_email': 'str',
            'ons_topic_id': 'str',
            'ons_subscription_id': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'domain_id': 'domainId',
            'subscription_email': 'subscriptionEmail',
            'ons_topic_id': 'onsTopicId',
            'ons_subscription_id': 'onsSubscriptionId',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._compartment_id = None
        self._domain_id = None
        self._subscription_email = None
        self._ons_topic_id = None
        self._ons_subscription_id = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateDomainGovernanceDetails.
        OCID of the tenancy.


        :return: The compartment_id of this CreateDomainGovernanceDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateDomainGovernanceDetails.
        OCID of the tenancy.


        :param compartment_id: The compartment_id of this CreateDomainGovernanceDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def domain_id(self):
        """
        **[Required]** Gets the domain_id of this CreateDomainGovernanceDetails.
        OCID of the domain.


        :return: The domain_id of this CreateDomainGovernanceDetails.
        :rtype: str
        """
        return self._domain_id

    @domain_id.setter
    def domain_id(self, domain_id):
        """
        Sets the domain_id of this CreateDomainGovernanceDetails.
        OCID of the domain.


        :param domain_id: The domain_id of this CreateDomainGovernanceDetails.
        :type: str
        """
        self._domain_id = domain_id

    @property
    def subscription_email(self):
        """
        **[Required]** Gets the subscription_email of this CreateDomainGovernanceDetails.
        The email to notify the user, and that the ONS subscription will be created with.


        :return: The subscription_email of this CreateDomainGovernanceDetails.
        :rtype: str
        """
        return self._subscription_email

    @subscription_email.setter
    def subscription_email(self, subscription_email):
        """
        Sets the subscription_email of this CreateDomainGovernanceDetails.
        The email to notify the user, and that the ONS subscription will be created with.


        :param subscription_email: The subscription_email of this CreateDomainGovernanceDetails.
        :type: str
        """
        self._subscription_email = subscription_email

    @property
    def ons_topic_id(self):
        """
        **[Required]** Gets the ons_topic_id of this CreateDomainGovernanceDetails.
        The ONS topic associated with this domain governance entity.


        :return: The ons_topic_id of this CreateDomainGovernanceDetails.
        :rtype: str
        """
        return self._ons_topic_id

    @ons_topic_id.setter
    def ons_topic_id(self, ons_topic_id):
        """
        Sets the ons_topic_id of this CreateDomainGovernanceDetails.
        The ONS topic associated with this domain governance entity.


        :param ons_topic_id: The ons_topic_id of this CreateDomainGovernanceDetails.
        :type: str
        """
        self._ons_topic_id = ons_topic_id

    @property
    def ons_subscription_id(self):
        """
        **[Required]** Gets the ons_subscription_id of this CreateDomainGovernanceDetails.
        The ONS subscription associated with this domain governance entity.


        :return: The ons_subscription_id of this CreateDomainGovernanceDetails.
        :rtype: str
        """
        return self._ons_subscription_id

    @ons_subscription_id.setter
    def ons_subscription_id(self, ons_subscription_id):
        """
        Sets the ons_subscription_id of this CreateDomainGovernanceDetails.
        The ONS subscription associated with this domain governance entity.


        :param ons_subscription_id: The ons_subscription_id of this CreateDomainGovernanceDetails.
        :type: str
        """
        self._ons_subscription_id = ons_subscription_id

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateDomainGovernanceDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this CreateDomainGovernanceDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateDomainGovernanceDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this CreateDomainGovernanceDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateDomainGovernanceDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this CreateDomainGovernanceDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateDomainGovernanceDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this CreateDomainGovernanceDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
